@@ -17,6 +17,7 @@
  *********************************************************************************/
 
 #include <com/sun/star/linguistic2/LinguServiceEventFlags.hpp>
+#include <osl/nlsupport.h>
 #include <libvoikko/voikko.h>
 
 #include "PropertyManager.hxx"
@@ -62,13 +63,16 @@ void PropertyManager::initialize() throw (uno::Exception) {
 	if (!voikko_initialized) {
 		isInitialized = sal_False;
 		#ifdef VOIKKO_STANDALONE_EXTENSION
-		const char * initerror = voikko_init_with_path(&voikko_handle, "fi_FI", 0,
-			OUStringToOString(getInstallationPath(), RTL_TEXTENCODING_UTF8).getStr());
+			rtl_TextEncoding encoding = osl_getTextEncodingFromLocale(0);
+			if (encoding == RTL_TEXTENCODING_DONTKNOW)
+				encoding = RTL_TEXTENCODING_UTF8;
+			voikkoErrorString = voikko_init_with_path(&voikko_handle, "fi_FI", 0,
+				OUStringToOString(getInstallationPath(), encoding).getStr());
 		#else
-		const char * initerror = voikko_init(&voikko_handle, "fi_FI", 0);
+			voikkoErrorString = voikko_init(&voikko_handle, "fi_FI", 0);
 		#endif
-		if (initerror) {
-			VOIKKO_DEBUG_2("Failed to initialize voikko: %s", initerror);
+		if (voikkoErrorString) {
+			VOIKKO_DEBUG_2("Failed to initialize voikko: %s", voikkoErrorString);
 			return;
 		}
 		voikko_set_string_option(voikko_handle, VOIKKO_OPT_ENCODING, "UTF-8");
@@ -127,6 +131,10 @@ sal_Bool PropertyManager::removeLinguServiceEventListener(
 	else return sal_False;
 }
 
+OUString PropertyManager::getInitializationStatus() {
+	if (isInitialized) return A2OU("OK");
+	else return A2OU(voikkoErrorString);
+}
 
 void PropertyManager::setProperties(const uno::Reference<beans::XPropertySet> & properties) {
 	beans::PropertyValue pValue;
